@@ -20,7 +20,7 @@ class DataSetReaderNER():
         # check inputs for consistancy
         assert len(sentence) == len(tags)
 
-        ids = []
+        input_ids = []
         target_tags = []
         tokens = []
         offsets = []
@@ -41,28 +41,28 @@ class DataSetReaderNER():
         offsets = offsets[:self.max_len - 2]
 
         # encode tokens for BERT
-        ids = self.transformer_tokenizer.encode(tokens)
+        input_ids = self.transformer_tokenizer.encode(tokens)
 
         # fill out other inputs for model.    
         # 8 is the 'O' encoding
         target_tags = [8] + target_tags + [8] 
-        masks = [1] * len(ids)
+        masks = [1] * len(input_ids)
         # set to 0, because we are not doing NSP or QA type task (across multiple sentences)
         # token_type_ids distinguishes sentences.
-        token_type_ids = [0] * len(ids) 
+        token_type_ids = [0] * len(input_ids) 
         offsets = [1] + offsets + [1]
 
         # Padding to max length 
         # compute padding length
-        padding_len = self.max_len - len(ids)
-        ids = ids + ([0] * padding_len)
+        padding_len = self.max_len - len(input_ids)
+        input_ids = input_ids + ([0] * padding_len)
         masks = masks + ([0] * padding_len)  
         offsets = offsets + ([0] * padding_len)
         token_type_ids = token_type_ids + ([0] * padding_len)
         # set to 8, since 'O' encoded as 8
         target_tags = target_tags + ([8] * padding_len)  
 
-        return {'ids' : torch.tensor(ids, dtype = torch.long),
+        return {'input_ids' : torch.tensor(input_ids, dtype = torch.long),
                 'masks' : torch.tensor(masks, dtype = torch.long),
                 'token_type_ids' : torch.tensor(token_type_ids, dtype = torch.long),
                 'target_tags' : torch.tensor(target_tags, dtype = torch.long),
